<?php

namespace App\Admin\Controllers;

use App\Models\DocterOrganization;
use Encore\Admin\Controllers\AdminController;
use Encore\Admin\Form;
use Encore\Admin\Grid;
use Encore\Admin\Show;

class SignUpController extends AdminController
{
    /**
     * Title for current resource.
     *
     * @var string
     */
    protected $title = '签约管理';

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new DocterOrganization());
        $grid->disableActions();
        $docter_id = \request('docter_id');
        $grid->filter(function ($filter){
            $filter->disableIdFilter();
            $filter->equal('docter_id','医生');
        });
        $grid->column('id', __('Id'));
        $grid->column('docter_id', __('医生id'));
        $grid->column('docter.name', __('医生姓名'));
        $grid->column('organization_id', __('机构id'));
        $grid->column('organization.name', __('机构名字'));
        $grid->column('state', __('审核状态'))->using([0=>'待审核',1=>'审核通过',2=>'审核拒绝']);
        $grid->column('created_at', __('创建时间'));
        $grid->column('updated_at', __('更新时间'));

        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     * @return Show
     */
    protected function detail($id)
    {
        $show = new Show(DocterOrganization::findOrFail($id));

        $show->field('id', __('Id'));
        $show->field('docter_id', __('Docter id'));
        $show->field('organization_id', __('Organization id'));
        $show->field('offices_id', __('Offices id'));
        $show->field('qualifications_id', __('Qualifications id'));
        $show->field('state', __('State'));
        $show->field('created_at', __('Created at'));
        $show->field('updated_at', __('Updated at'));

        return $show;
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        $form = new Form(new DocterOrganization());

        $form->number('docter_id', __('Docter id'));
        $form->number('organization_id', __('Organization id'));
        $form->number('offices_id', __('Offices id'));
        $form->number('qualifications_id', __('Qualifications id'));
        $form->number('state', __('State'));

        return $form;
    }
}
